Package: rb3
Title: Download and Parse Public Data Released by B3 Exchange
Description: Download and parse public files released by B3 and convert them
    into useful formats and data structures common to data analysis
    practitioners.
Version: 0.1.0
Authors@R: c(person("Wilson", "Freitas",
                    email = "wilson.freitas@gmail.com",
                    role = c("aut", "cre")),
             person("Marcelo", "Perlin",
                    email = "marceloperlin@gmail.com",
                    role = "aut"))
License: MIT + file LICENSE
Depends: R (>= 4.1.0),
Imports: bizdays, stringr, stringi, cli, readr, dplyr, arrow, httr,
        jsonlite, purrr, rlang, yaml, digest, base64enc, XML, R.utils,
        lubridate, DBI, RSQLite
Suggests: testthat, knitr, rmarkdown, ggplot2, covr, scales, magrittr,
        tibble, withr, tidyr, vcr (>= 0.6.0)
Collate: 'types.R' 'fields.R' 'registry.R' 'template.R' 'meta.R'
        'read-marketdata.R' 'fetch-marketdata.R'
        'download-marketdata.R' 'scraper-futures.R'
        'scraper-cotahist.R' 'scraper-yc.R' 'scraper-indexes.R'
        'readers.R' 'downloaders.R' 'rb3-package.R' 'zzz.R'
BugReports: https://github.com/ropensci/rb3/issues
URL: https://github.com/ropensci/rb3, https://ropensci.github.io/rb3/
VignetteBuilder: knitr
RoxygenNote: 7.3.2
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2025-07-07 09:01:51 UTC; wilson
Author: Wilson Freitas [aut, cre],
  Marcelo Perlin [aut]
Maintainer: Wilson Freitas <wilson.freitas@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-07 09:20:02 UTC
Built: R 4.6.0; ; 2026-04-30 01:36:09 UTC; unix
