# Generated by roxygen2: do not edit by hand

S3method("$",registry)
S3method("$",type)
S3method("$<-",registry)
S3method("$<-",type)
S3method("[[",registry)
S3method("[[<-",registry)
S3method(base::as.data.frame,fields)
S3method(base::length,registry)
S3method(base::names,registry)
S3method(base::print,fields)
S3method(base::print,meta)
S3method(base::print,parts)
S3method(base::print,registry)
S3method(base::print,registry_class)
S3method(base::print,template)
S3method(template_dataset,default)
S3method(template_dataset,template)
S3method(template_meta_load,default)
S3method(template_meta_load,template)
S3method(template_meta_new,default)
S3method(template_meta_new,template)
export(code2month)
export(cotahist_filter_bdr)
export(cotahist_filter_equity)
export(cotahist_filter_equity_options)
export(cotahist_filter_etf)
export(cotahist_filter_fiagro)
export(cotahist_filter_fidc)
export(cotahist_filter_fii)
export(cotahist_filter_fund_options)
export(cotahist_filter_index)
export(cotahist_filter_index_options)
export(cotahist_filter_unit)
export(cotahist_get)
export(cotahist_options_by_symbols_get)
export(download_marketdata)
export(fetch_marketdata)
export(futures_get)
export(indexes_composition_get)
export(indexes_current_portfolio_get)
export(indexes_get)
export(indexes_historical_data_get)
export(indexes_theoretical_portfolio_get)
export(list_templates)
export(maturitycode2date)
export(meta_db_connection)
export(rb3_bootstrap)
export(read_marketdata)
export(template_dataset)
export(template_meta_create_or_load)
export(template_meta_load)
export(template_meta_new)
export(template_retrieve)
export(yc_brl_get)
export(yc_brl_with_futures_get)
export(yc_get)
export(yc_ipca_get)
export(yc_ipca_with_futures_get)
export(yc_usd_get)
export(yc_usd_with_futures_get)
importFrom(bizdays,add.bizdays)
importFrom(bizdays,bizdayse)
importFrom(bizdays,bizseq)
importFrom(bizdays,following)
importFrom(bizdays,getdate)
importFrom(bizdays,load_builtin_calendars)
importFrom(bizdays,preceding)
importFrom(dplyr,collect)
importFrom(dplyr,filter)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(rlang,.data)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_ends)
importFrom(stringr,str_glue)
importFrom(stringr,str_length)
importFrom(stringr,str_match)
importFrom(stringr,str_pad)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_starts)
importFrom(stringr,str_sub)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_trim)
